@@ -2,10 +2,10 @@ use bevy::prelude::*;
 
 use bevy_inspector_egui::{widgets::InspectableButton, Inspectable, InspectorPlugin};
 
-#[derive(Default)]
+#[derive(Component, Default)]
 struct Print;
 
-#[derive(Default, Inspectable)]
+#[derive(Inspectable, Default)]
 struct Inspector {
     shape: Shape,
     #[inspectable(label = "", text = "Print")]
@@ -45,7 +45,7 @@ impl Default for Shape {
 }
 
 fn main() {
-    App::build()
+    App::new()
         .insert_resource(ClearColor(Color::rgb(0.039, 0.055, 0.078)))
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<Inspector>::new())
