@@ -1,3 +1,6 @@
+fn main() {}
+
+/*
 use bevy::prelude::*;
 use bevy_inspector_egui::{widgets::InspectorQuerySingle, InspectorPlugin};
 use bevy_rapier3d::{
@@ -8,7 +11,7 @@ use bevy_rapier3d::{
 };
 
 fn main() {
-    App::build()
+    App::new()
         .insert_resource(Msaa { samples: 4 })
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<InspectorQuerySingle<Entity, With<Cube>>>::new())
@@ -65,7 +68,7 @@ fn setup(
         })
         .insert(ColliderPositionSync::Discrete);
 
-    commands.spawn_bundle(LightBundle {
+    commands.spawn_bundle(PointLightBundle {
         transform: Transform::from_xyz(4.0, 8.0, 4.0),
         ..Default::default()
     });
@@ -74,3 +77,5 @@ fn setup(
         ..Default::default()
     });
 }
+
+*/
