@@ -64,8 +64,13 @@ struct NoiseSettings {
 struct NonInspectable;
 
 fn main() {
-    App::build()
+    App::new()
         .add_plugins(DefaultPlugins)
         .add_plugin(InspectorPlugin::<Data>::new())
+        .add_system(setup.system())
         .run();
 }
+
+fn setup(mut commands: Commands) {
+    commands.spawn_bundle(PerspectiveCameraBundle::default());
+}
