@@ -15,7 +15,7 @@ use crate::InspectableRegistry;
 /// use bevy_inspector_egui::WorldInspectorPlugin;
 ///
 /// fn main() {
-///     App::build()
+///     App::new()
 ///         .add_plugins(DefaultPlugins)
 ///         .add_plugin(WorldInspectorPlugin::new())
 ///         .add_startup_system(setup.system())
@@ -44,9 +44,9 @@ use crate::InspectableRegistry;
 /// pub struct MyPlugin;
 ///
 /// impl Plugin for MyPlugin {
-///     fn build(&self, app: &mut AppBuilder) {
+///     fn build(&self, app: &mut App) {
 ///         let mut registry = app
-///             .world_mut()
+///             .world
 ///             .get_resource_or_insert_with(InspectableRegistry::default);
 ///
 ///         registry.register::<MyComponent>();
@@ -54,7 +54,7 @@ use crate::InspectableRegistry;
 /// }
 /// ```
 ///
-/// Components can be registered in `main` function aswell, just use your [`bevy::app::AppBuilder`]
+/// Components can be registered in `main` function aswell, just use your [`bevy::app::App`]
 /// instance to do so.
 
 pub struct WorldInspectorPlugin<F = ()>(PhantomData<fn() -> F>);
@@ -75,9 +75,10 @@ impl WorldInspectorPlugin {
     /// ```rust,no_run
     /// # use bevy::prelude::*;
     /// # use bevy_inspector_egui::WorldInspectorPlugin;
+    /// #[derive(Component)]
     /// struct Show;
     ///
-    /// App::build()
+    /// App::new()
     ///   .add_plugin(WorldInspectorPlugin::new().filter::<With<Show>>())
     ///   .run();
     /// ```
@@ -91,12 +92,12 @@ where
     F: WorldQuery + 'static,
     F::Fetch: FilterFetch,
 {
-    fn build(&self, app: &mut AppBuilder) {
-        if !app.world_mut().contains_resource::<EguiContext>() {
+    fn build(&self, app: &mut App) {
+        if !app.world.contains_resource::<EguiContext>() {
             app.add_plugin(EguiPlugin);
         }
 
-        let world = app.world_mut();
+        let world = &mut app.world;
         world.get_resource_or_insert_with(WorldInspectorParams::default);
         world.get_resource_or_insert_with(InspectableRegistry::default);
 
@@ -111,26 +112,30 @@ where
 {
     let world_ptr = world as *mut _;
 
-    let params = world.get_resource::<WorldInspectorParams>().unwrap();
-    if !params.enabled {
-        return;
-    }
-
     let egui_context = world.get_resource::<EguiContext>().expect("EguiContext");
-    let ctx = match egui_context.try_ctx_for_window(params.window) {
-        Some(ctx) => ctx,
-        None => return,
+    let ctx = {
+        let params = world.get_resource::<WorldInspectorParams>().unwrap();
+        if !params.enabled {
+            return;
+        }
+        let ctx = match egui_context.try_ctx_for_window(params.window) {
+            Some(ctx) => ctx,
+            None => return,
+        };
+        ctx
     };
+    let world: &mut World = unsafe { &mut *world_ptr };
+    let mut params = world.get_resource_mut::<WorldInspectorParams>().unwrap();
 
     let mut is_open = true;
     egui::Window::new("World")
         .open(&mut is_open)
-        .scroll(true)
+        .vscroll(true)
         .show(ctx, |ui| {
             crate::plugin::default_settings(ui);
             let world: &mut World = unsafe { &mut *world_ptr };
             let mut ui_context = WorldUIContext::new(world, Some(egui_context.ctx()));
-            ui_context.world_ui::<F>(ui, &params);
+            ui_context.world_ui::<F>(ui, &mut params);
         });
 
     if !is_open {
